@@ -36,7 +36,7 @@ from .objects.message import MessageGroup, factory_message
 from .objects.number_status import NumberStatus
 from .wapi_js_wrapper import WapiJsWrapper
 
-__version__ = '1.3.1'
+__version__ = '1.3.2'
 
 
 class WhatsAPIDriverStatus(object):
@@ -166,6 +166,8 @@ class WhatsAPIDriver(object):
                 # Disable Flash
                 self._profile.set_preference('dom.ipc.plugins.enabled.libflashplayer.so',
                                              'false')
+            # Defaults to no proxy
+            self._profile.set_preference("network.proxy.type", 0)
             if proxy is not None:
                 self.set_proxy(proxy)
 
